@@ -432,6 +432,7 @@ class Impira(Tool):
         skip_type_inference=False,
         skip_upload=False,
         add_files=False,
+        skip_missing_files=False,
         skip_new_fields=False,
         collection_name=None,
         max_fields=-1,
@@ -511,6 +512,9 @@ class Impira(Tool):
                 else:
                     break
 
+            if skip_missing_files:
+                entries = [e for e in entries if e.fname.name in uids]
+
             file_data = [uids[e.fname.name] for e in entries]
 
         log.info("File uids: %s", [r["uid"] for r in file_data])
@@ -559,7 +563,7 @@ class Impira(Tool):
         new_fields = []
         field_specs = []
         field_names_to_update = set()
-        for f in schema[:max_fields]:
+        for f in schema[:max_fields] if max_fields != -1 else schema:
             field_type = f.field_type
             first_labels = labels[0]
             if f.name in first_labels and isinstance(first_labels[f.name], ScalarLabel) and not skip_type_inference:
@@ -606,7 +610,8 @@ class Impira(Tool):
                 field_specs.append(field_type.build_field_spec(f.name, f.path))
                 field_names_to_update.add(f.name)
 
-        log.info("Creating fields")
+        log.info("Creating fields: %s" % (field_names_to_update))
+
         if len(field_specs) > 0:
             conn.create_fields(collection_uid, field_specs)
 
@@ -691,7 +696,7 @@ class Impira(Tool):
         log.info("Done!")
 
     @validate_arguments
-    def snapshot(self, collection_uid: str, use_original_filenames=False):
+    def snapshot(self, collection_uid: str, use_original_filenames=False, labeled_files_only=False):
         log = self._log()
 
         conn = self._conn()
@@ -707,6 +712,9 @@ class Impira(Tool):
             for row in resp["data"]
         ]
 
+        if labeled_files_only:
+            records = [r for r in records if r["record"] is not None]
+
         assert len(records) == len(set([r["name"] for r in records])), "Expected each filename to be unique"
 
         return doc_schema, records
